@@ -1,6 +1,7 @@
 import os
 import json
 
+
 def _config_filepath():
     home = "USERPROFILE" if os.name == "nt" else "HOME"
     configDir = os.path.join(os.environ[home], ".tla/")
@@ -26,7 +27,7 @@ def _check():
     with open(configFile, "r") as config:
         try:
             jsonObj = json.load(config)
-        except:
+        except Exception:
             _noLoginMessage()
 
         if "access_key" not in jsonObj.keys():
